#!/usr/bin/env python
# -*- coding: utf-8 -*-
# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4

###############################################################################
# OpenLP - Open Source Lyrics Projection                                      #
# --------------------------------------------------------------------------- #
# Copyright (c) 2008-2011 Raoul Snyman                                        #
# Portions copyright (c) 2008-2011 Tim Bentley, Gerald Britton, Jonathan      #
# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
# Meinert Jordan, Armin Köhler, Edwin Lunando, Joshua Miller, Stevan Pettit,  #
# Andreas Preikschat, Mattias Põldaru, Christian Richter, Philip Ridout,      #
# Simon Scudder, Jeffrey Smith, Maikel Stuivenberg, Martin Thompson, Jon      #
# Tibble, Dave Warnock, Frode Woldsund                                        #
# --------------------------------------------------------------------------- #
# This program is free software; you can redistribute it and/or modify it     #
# under the terms of the GNU General Public License as published by the Free  #
# Software Foundation; version 2 of the License.                              #
#                                                                             #
# This program is distributed in the hope that it will be useful, but WITHOUT #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    #
# more details.                                                               #
#                                                                             #
# You should have received a copy of the GNU General Public License along     #
# with this program; if not, write to the Free Software Foundation, Inc., 59  #
# Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
###############################################################################

"""
Configuration file for pytest framework.
"""

from openlp.core import main as openlp_main


# Test function argument to make openlp gui instance persistent for all tests.
# All test cases have to access the same instance. To allow create multiple
# instances it would be necessary use diffrent configuraion and data files.
# Created instance will use your OpenLP settings.
def pytest_funcarg__openlpapp(request):
    def setup():
        return openlp_main(['--testing'])
    def teardown(app):
        pass
    return request.cached_setup(setup=setup, teardown=teardown, scope='session')



# -*- coding: utf-8 -*-
# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4

###############################################################################
# OpenLP - Open Source Lyrics Projection                                      #
# --------------------------------------------------------------------------- #
# Copyright (c) 2008-2014 Raoul Snyman                                        #
# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
# Frode Woldsund, Martin Zibricky                                             #
# --------------------------------------------------------------------------- #
# This program is free software; you can redistribute it and/or modify it     #
# under the terms of the GNU General Public License as published by the Free  #
# Software Foundation; version 2 of the License.                              #
#                                                                             #
# This program is distributed in the hope that it will be useful, but WITHOUT #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    #
# more details.                                                               #
#                                                                             #
# You should have received a copy of the GNU General Public License along     #
# with this program; if not, write to the Free Software Foundation, Inc., 59  #
# Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
###############################################################################
"""
The :mod:`upgrade` module provides a way for the database and schema that is the
backend for the Songs plugin
"""

from sqlalchemy import Column, Table, types
from sqlalchemy.sql.expression import func
from migrate.changeset.constraint import ForeignKeyConstraint

__version__ = 3

def upgrade_setup(metadata):
    """
    Set up the latest revision all tables, with reflection, needed for the
    upgrade process. If you want to drop a table, you need to remove it from
    here, and add it to your upgrade function.
    """
    tables = {
        u'authors': Table(u'authors', metadata, autoload=True),
        u'media_files': Table(u'media_files', metadata, autoload=True),
        u'song_books': Table(u'song_books', metadata, autoload=True),
        u'songs': Table(u'songs', metadata, autoload=True),
        u'topics': Table(u'topics', metadata, autoload=True),
        u'authors_songs': Table(u'authors_songs', metadata, autoload=True),
        u'songs_topics': Table(u'songs_topics', metadata, autoload=True)
    }
    return tables


def upgrade_1(session, metadata, tables):
    """
    Version 1 upgrade.

    This upgrade removes the many-to-many relationship between songs and
    media_files and replaces it with a one-to-many, which is far more
    representative of the real relationship between the two entities.

    In order to facilitate this one-to-many relationship, a song_id column is
    added to the media_files table, and a weight column so that the media
    files can be ordered.
    """
    Table(u'media_files_songs', metadata, autoload=True).drop(checkfirst=True)
    Column(u'song_id', types.Integer(), default=None)\
        .create(table=tables[u'media_files'])
    Column(u'weight', types.Integer(), default=0)\
        .create(table=tables[u'media_files'])
    if metadata.bind.url.get_dialect().name != 'sqlite':
        # SQLite doesn't support ALTER TABLE ADD CONSTRAINT
        ForeignKeyConstraint([u'song_id'], [u'songs.id'],
            table=tables[u'media_files']).create()


def upgrade_2(session, metadata, tables):
    """
    Version 2 upgrade.

    This upgrade adds a create_date and last_modified date to the songs table
    """
    Column(u'create_date', types.DateTime(), default=func.now())\
        .create(table=tables[u'songs'])
    Column(u'last_modified', types.DateTime(), default=func.now())\
        .create(table=tables[u'songs'])


def upgrade_3(session, metadata, tables):
    """
    Version 3 upgrade.

    This upgrade adds a temporary song flag to the songs table
    """
    Column(u'temporary', types.Boolean(), default=False)\
        .create(table=tables[u'songs'])




# -*- coding: utf-8 -*-
# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4

###############################################################################
# OpenLP - Open Source Lyrics Projection                                      #
# --------------------------------------------------------------------------- #
# Copyright (c) 2008-2014 Raoul Snyman                                        #
# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
# Frode Woldsund, Martin Zibricky                                             #
# --------------------------------------------------------------------------- #
# This program is free software; you can redistribute it and/or modify it     #
# under the terms of the GNU General Public License as published by the Free  #
# Software Foundation; version 2 of the License.                              #
#                                                                             #
# This program is distributed in the hope that it will be useful, but WITHOUT #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    #
# more details.                                                               #
#                                                                             #
# You should have received a copy of the GNU General Public License along     #
# with this program; if not, write to the Free Software Foundation, Inc., 59  #
# Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
###############################################################################

from PyQt4 import QtGui

from openlp.core.lib import translate, build_icon
from openlp.core.lib.ui import create_button_box


class Ui_FirstTimeLanguageDialog(object):
    def setupUi(self, languageDialog):
        languageDialog.setObjectName(u'languageDialog')
        languageDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
        languageDialog.resize(300, 50)
        self.dialogLayout = QtGui.QVBoxLayout(languageDialog)
        self.dialogLayout.setContentsMargins(8, 8, 8, 8)
        self.dialogLayout.setSpacing(8)
        self.dialogLayout.setObjectName(u'dialogLayout')
        self.infoLabel = QtGui.QLabel(languageDialog)
        self.infoLabel.setObjectName(u'infoLabel')
        self.dialogLayout.addWidget(self.infoLabel)
        self.languageLayout = QtGui.QHBoxLayout()
        self.languageLayout.setObjectName(u'languageLayout')
        self.languageLabel = QtGui.QLabel(languageDialog)
        self.languageLabel.setObjectName(u'languageLabel')
        self.languageLayout.addWidget(self.languageLabel)
        self.languageComboBox = QtGui.QComboBox(languageDialog)
        self.languageComboBox.setSizeAdjustPolicy(
            QtGui.QComboBox.AdjustToContents)
        self.languageComboBox.setObjectName("languageComboBox")
        self.languageLayout.addWidget(self.languageComboBox)
        self.dialogLayout.addLayout(self.languageLayout)
        self.buttonBox = create_button_box(languageDialog, u'buttonBox',
            [u'cancel', u'ok'])
        self.dialogLayout.addWidget(self.buttonBox)

        self.retranslateUi(languageDialog)
        self.setMaximumHeight(self.sizeHint().height())

    def retranslateUi(self, languageDialog):
        self.setWindowTitle(translate('OpenLP.FirstTimeLanguageForm',
                'Select Translation'))
        self.infoLabel.setText(translate('OpenLP.FirstTimeLanguageForm',
            'Choose the translation you\'d like to use in OpenLP.'))
        self.languageLabel.setText(translate('OpenLP.FirstTimeLanguageForm',
            'Translation:'))



# -*- coding: utf-8 -*-
# vim: autoindent shiftwidth=4 expandtab textwidth=80 tabstop=4 softtabstop=4

###############################################################################
# OpenLP - Open Source Lyrics Projection                                      #
# --------------------------------------------------------------------------- #
# Copyright (c) 2008-2014 Raoul Snyman                                        #
# Portions copyright (c) 2008-2014 Tim Bentley, Gerald Britton, Jonathan      #
# Corwin, Samuel Findlay, Michael Gorven, Scott Guerrieri, Matthias Hub,      #
# Meinert Jordan, Armin Köhler, Erik Lundin, Edwin Lunando, Brian T. Meyer.   #
# Joshua Miller, Stevan Pettit, Andreas Preikschat, Mattias Põldaru,          #
# Christian Richter, Philip Ridout, Simon Scudder, Jeffrey Smith,             #
# Maikel Stuivenberg, Martin Thompson, Jon Tibble, Dave Warnock,              #
# Frode Woldsund, Martin Zibricky                                             #
# --------------------------------------------------------------------------- #
# This program is free software; you can redistribute it and/or modify it     #
# under the terms of the GNU General Public License as published by the Free  #
# Software Foundation; version 2 of the License.                              #
#                                                                             #
# This program is distributed in the hope that it will be useful, but WITHOUT #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    #
# more details.                                                               #
#                                                                             #
# You should have received a copy of the GNU General Public License along     #
# with this program; if not, write to the Free Software Foundation, Inc., 59  #
# Temple Place, Suite 330, Boston, MA 02111-1307 USA                          #
###############################################################################

from PyQt4 import QtGui

from openlp.core.lib import translate, build_icon
from openlp.core.lib.ui import create_button_box


class Ui_ThemeLayoutDialog(object):
    def setupUi(self, themeLayoutDialog):
        themeLayoutDialog.setObjectName(u'themeLayoutDialogDialog')
        themeLayoutDialog.setWindowIcon(build_icon(u':/icon/openlp-logo.svg'))
        self.previewLayout = QtGui.QVBoxLayout(themeLayoutDialog)
        self.previewLayout.setObjectName(u'previewLayout')
        self.previewArea = QtGui.QWidget(themeLayoutDialog)
        self.previewArea.setObjectName(u'previewArea')
        self.previewAreaLayout = QtGui.QGridLayout(self.previewArea)
        self.previewAreaLayout.setMargin(0)
        self.previewAreaLayout.setColumnStretch(0, 1)
        self.previewAreaLayout.setRowStretch(0, 1)
        self.previewAreaLayout.setObjectName(u'previewAreaLayout')
        self.themeDisplayLabel = QtGui.QLabel(self.previewArea)
        self.themeDisplayLabel.setFrameShape(QtGui.QFrame.Box)
        self.themeDisplayLabel.setScaledContents(True)
        self.themeDisplayLabel.setObjectName(u'themeDisplayLabel')
        self.previewAreaLayout.addWidget(self.themeDisplayLabel)
        self.previewLayout.addWidget(self.previewArea)
        self.mainColourLabel = QtGui.QLabel(self.previewArea)
        self.mainColourLabel.setObjectName(u'mainColourLabel')
        self.previewLayout.addWidget(self.mainColourLabel)
        self.footerColourLabel = QtGui.QLabel(self.previewArea)
        self.footerColourLabel.setObjectName(u'footerColourLabel')
        self.previewLayout.addWidget(self.footerColourLabel)
        self.buttonBox = create_button_box(themeLayoutDialog, u'buttonBox',
            [u'ok'])
        self.previewLayout.addWidget(self.buttonBox)
        self.retranslateUi(themeLayoutDialog)

    def retranslateUi(self, themeLayoutDialog):
        themeLayoutDialog.setWindowTitle(
            translate('OpenLP.StartTimeForm', 'Theme Layout'))
        self.mainColourLabel.setText(translate('OpenLP.StartTimeForm',
            'The blue box shows the main area.'))
        self.footerColourLabel.setText(translate('OpenLP.StartTimeForm',
            'The red box shows the footer.'))

